#
# spec file for package gpgme
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define psuffix %{nil}
%global flavor qt%{nil}
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_without python3
%bcond_with qt
%endif
%if "%{flavor}" == "qt"
%define psuffix qt
%bcond_with python3
%bcond_without qt
%if 0%{suse_version} == 1600 && ! 0%{?is_opensuse}
ExclusiveArch:  donotbuild
%endif
%endif
%if "%{flavor}" == "qt6"
%define psuffix qt6
%bcond_with python3
%bcond_without qt6
%endif

%if 0%{suse_version} >= 1550 || "%{?pythons}" == "python311"
%bcond_without replace_distutils
%else
# Keep deprecated distutils for Python 3.6 on 15.x
%bcond_with replace_distutils
%endif

Name:           gpgme%{psuffix}
Version:        1.24.3
Release:        2.1
Summary:        Programmatic library interface to GnuPG
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Security
URL:            https://www.gnupg.org/related_software/gpgme/
Source:         https://www.gnupg.org/ftp/gcrypt/gpgme/gpgme-%{version}.tar.bz2
Source1:        https://www.gnupg.org/ftp/gcrypt/gpgme/gpgme-%{version}.tar.bz2.sig
Source2:        baselibs.conf
# https://www.gnupg.org/signature_key.html
Source3:        https://gnupg.org/signature_key.asc#/gpgme.keyring
# used to have a fixed timestamp
Source99:       gpgme.changes
# PATCH-FIX-OPENSUSE gpgme-suse-nobetasuffix.patch code@bnavigator.de -- remove "-unknown" betasuffix boo#1205197
Patch2:         gpgme-suse-nobetasuffix.patch
Patch4:         gpgme-fix-python-install.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gpg2 >= 2.4.1
BuildRequires:  libassuan-devel >= 2.4.2
BuildRequires:  libgpg-error-devel >= 1.47
BuildRequires:  pkgconfig
BuildRequires:  swig
%if %{with python3}
BuildRequires:  %{python_module devel}
BuildRequires:  python-rpm-macros
%if %{with replace_distutils}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 62.4}
BuildRequires:  %{python_module wheel}
%endif
%endif
%if %{with qt}
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
%endif
%if %{with qt6}
%if 0%{?suse_version} < 1550
# The default compiler is too old for Qt6, use the newest
# version available in the :Update repo
BuildRequires:  gcc12-c++
BuildRequires:  gcc12-PIE
%endif
BuildRequires:  pkgconfig(Qt6Core) >= 6.4.0
BuildRequires:  pkgconfig(Qt6Test)
%endif
%if 0%{?suse_version} >= 1550
# TW: generate subpackages for every python3 flavor
%define python_subpackage_only 1
%python_subpackages
%else
%define python_sitearch %python3_sitearch
%define python_version %python3_version
%define python_files() -n python3-%{**}
%endif

%description
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management. It uses GnuPG as its back-end.

%package -n libgpgme11
Summary:        Programmatic library interface to GnuPG
Group:          System/Libraries
Requires:       gpg2

%description -n libgpgme11
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management. It uses GnuPG as its back-end.

%package -n libgpgme-devel
Summary:        Development files for GPGME, a C library for accessing GnuPG
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libgpg-error-devel
Requires:       libgpgme11 = %{version}
%requires_ge    libassuan-devel
Provides:       gpgme-devel = %{version}
Obsoletes:      gpgme-devel < %{version}

%description -n libgpgme-devel
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This subpackage contains the headers needed for building applications
making use of libgpgme.

%package -n libgpgmepp6
Summary:        Programmatic C++ library interface to GnuPG
Group:          System/Libraries
Requires:       gpg2

%description -n libgpgmepp6
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This package contains the C++ bindings.

%package -n libgpgmepp-devel
Summary:        Development files for libgpgmepp, a C++ library for accessing GnuPG
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libgpg-error-devel
Requires:       libgpgme-devel = %{version}
Requires:       libgpgmepp6 = %{version}
# This avoids requiring CMake at build time for the default flavor
Provides:       cmake(Gpgmepp) = %{version}
%requires_ge    libassuan-devel

%description -n libgpgmepp-devel
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This subpackage contains the headers needed for building applications
making use of libgpgmepp.

%if 0%{?python_subpackage_only}
%package -n python-gpg
Summary:        Python %{python_version} bindings for GPGME, a library for accessing GnuPG
Group:          Development/Languages/Python

%description -n python-gpg
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This package contains the bindings to use the library from Python %{python_version} applications.

%else

%package -n python3-gpg
Summary:        Python 3 bindings for GPGME, a library for accessing GnuPG
Group:          Development/Languages/Python

%description -n python3-gpg
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This package contains the bindings to use the library from Python 3 applications.
%endif

%package -n libqgpgme15
Summary:        Programmatic Qt 5 library interface to GnuPG
Group:          System/Libraries
Requires:       gpg2

%description -n libqgpgme15
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This package contains the Qt 5 bindings.

%package -n libqgpgme-devel
Summary:        Development files for libqgpgme, a Qt 5 library for accessing GnuPG
Group:          Development/Libraries/C and C++
Requires:       libgpgme-devel = %{version}
Requires:       libgpgmepp-devel = %{version}
Requires:       libqgpgme15 = %{version}

%description -n libqgpgme-devel
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This package contains the bindings to use the library in Qt 5 C++ applications.

%package -n libqgpgmeqt6-15
Summary:        Programmatic Qt 6 library interface to GnuPG
Group:          System/Libraries
Requires:       gpg2

%description -n libqgpgmeqt6-15
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This package contains the Qt 6 bindings.

%package -n libqgpgmeqt6-devel
Summary:        Development files for libqgpgmeqt6, a Qt library for accessing GnuPG
Group:          Development/Libraries/C and C++
Requires:       libgpgme-devel = %{version}
Requires:       libgpgmepp-devel = %{version}
Requires:       libqgpgmeqt6-15 = %{version}
# The include folders have the same name in both libqgpgme-devel and libqgpgmeqt6-devel
Conflicts:      libqgpgme-devel

%description -n libqgpgmeqt6-devel
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification, and key
management.

This package contains the bindings to use the library in Qt 6 C++ applications.

%prep
%autosetup -N -n gpgme-%{version}
%if %{with replace_distutils}
%patch -p1 -P2
%endif
%if 0%{suse_version} > 1500
# Note: rpm in 15.x does not know about the autopatch -m flag.
# Need to apply every additional patch explicitly, if any.
%autopatch -p1 -m4
%endif

%build
./autogen.sh
build_timestamp=$(date -u +%{Y}-%{m}-%{dT}%{H}:%{M}+0000 -r %{SOURCE99})
languages="cl cpp"

%if %{with python3}
languages="${languages} python"
%endif

%if %{with qt}
languages="cpp qt"
%endif

%if %{with qt6}
languages="cpp qt6"
%if 0%{?suse_version} < 1550
# Qt6 needs full c++-17 support
export CXX=g++-12 CC=gcc-12 CPP=cpp-12
%endif
%endif

%define _configure ../configure
mkdir build
pushd build
%configure \
	--disable-silent-rules \
	--disable-static \
	--disable-fd-passing \
	--enable-languages="${languages}" \
	--enable-build-timestamp="${build_timestamp}"
%make_build
popd

%install
pushd build
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
chmod -x %{buildroot}%{_libdir}/cmake/Gpgmepp/*.cmake

%if %{with qt} || %{with qt6}
rm -r %{buildroot}%{_bindir}
rm -r %{buildroot}%{_datadir}/aclocal/gpgme*
rm -r %{buildroot}%{_includedir}/gpgme*
rm -r %{buildroot}%{_infodir}/gpgme*
rm -r %{buildroot}%{_libdir}/cmake/Gpgmepp
rm -r %{buildroot}%{_libdir}/libgpgme*
rm -r %{buildroot}%{_libdir}/pkgconfig/gpgme*
rm -r %{buildroot}%{_mandir}/man1/gpgme-json.*
%endif
popd

%check
GPGME_DEBUG=2:mygpgme.log %make_build check skip=%{?qt_skip:%{qt_skip}} || cat $(find -name mygpgme.log -type f)

%if %{with qt}
%ldconfig_scriptlets -n libqgpgme15
%endif

%if %{with qt6}
%ldconfig_scriptlets -n libqgpgmeqt6-15
%endif

%if %{without qt} && %{without qt6}
%ldconfig_scriptlets -n libgpgme11
%ldconfig_scriptlets -n libgpgmepp6
%endif

%if %{without qt} && %{without qt6}
%files
%license COPYING COPYING.LESSER LICENSES
%doc AUTHORS ChangeLog ChangeLog-2011 README NEWS THANKS TODO VERSION
%{_bindir}/gpgme-tool
%{_bindir}/gpgme-json
%dir %{_datadir}/common-lisp
%dir %{_datadir}/common-lisp/source
%{_datadir}/common-lisp/source/gpgme
%{_infodir}/gpgme*
%{_mandir}/man1/gpgme-json.*

%files -n libgpgme11
%license COPYING COPYING.LESSER LICENSES
%{_libdir}/libgpgme.so.*

%files -n libgpgme-devel
%license COPYING COPYING.LESSER LICENSES
%{_libdir}/libgpgme.so
%{_bindir}/gpgme-config
%{_datadir}/aclocal/gpgme.m4
%{_includedir}/gpgme.h
%{_libdir}/pkgconfig/gpgme.pc
%{_libdir}/pkgconfig/gpgme-glib.pc

%files -n libgpgmepp6
%license COPYING COPYING.LESSER LICENSES
%{_libdir}/libgpgmepp.so.*

%files -n libgpgmepp-devel
%license COPYING COPYING.LESSER LICENSES
%{_libdir}/libgpgmepp.so
%{_includedir}/gpgme++
%dir %{_libdir}/cmake
%dir %{_libdir}/cmake/Gpgmepp
%{_libdir}/cmake/Gpgmepp/GpgmeppConfig*.cmake
%{_libdir}/pkgconfig/gpgmepp.pc
%endif

%if %{with python3}
%files %{python_files gpg}
%license COPYING COPYING.LESSER LICENSES
%{python_sitearch}/gpg
%{python_sitearch}/gpg-%{version}*.egg-info
%endif

%if %{with qt}
%files -n libqgpgme15
%license COPYING COPYING.LESSER LICENSES
%{_libdir}/libqgpgme.so.*

%files -n libqgpgme-devel
%license COPYING COPYING.LESSER LICENSES
%{_includedir}/qgpgme-qt5/
%dir %{_libdir}/cmake
%dir %{_libdir}/cmake/QGpgme
%{_libdir}/cmake/QGpgme/*.cmake
%{_libdir}/libqgpgme.so
%endif

%if %{with qt6}
%files -n libqgpgmeqt6-15
%license COPYING COPYING.LESSER LICENSES
%{_libdir}/libqgpgmeqt6.so.*

%files -n libqgpgmeqt6-devel
%license COPYING COPYING.LESSER LICENSES
%{_includedir}/qgpgme-qt6/
%dir %{_libdir}/cmake
%dir %{_libdir}/cmake/QGpgmeQt6
%{_libdir}/cmake/QGpgmeQt6/*.cmake
%{_libdir}/libqgpgmeqt6.so
%endif

%changelog
* Thu May 29 2025 Antonio Larrosa <alarrosa@suse.com>
- Do not build the qt5 flavor in SLE16 where Qt5 won't be
  available.
* Fri May 23 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.24.3:
  * cpp: Ensure that all transitions go from one state to a different
    state
  * cpp: Ensure correct expiration time on 32-bit arch with 64-bit
    time_t
* Thu Feb 20 2025 Matej Cepl <mcepl@cepl.eu>
- Don't own content of all common-lisp directories, just own the
  directories themselves (adding %%dir in front of them). Prevents
  duplicate ownership of the Common Lisp files.
* Mon Feb 10 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 1.24.2:
  * Fix regression for RSA in gpgme_pubkey_algo_string
  * Prevent failing tests after 2027-05-15
- drop python313.patch, is included
* Wed Dec 11 2024 Lucas Mulling <lucas.mulling@suse.com>
- Update to 1.24.1:
  * Support the Kyber algorithm in key listings.
  * Allow building on some older Linux platforms.  [rM4a62318422]
  * Interface changes relative to the 1.24.0 release:
    GPGME_PK_KYBER                          NEW enum value.
* Fri Nov 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add gpgme-fix-python-install.patch: Fix the installation of the
  python bindings without having to move them around manually.
* Wed Nov 20 2024 Pedro Monreal <pmonreal@suse.com>
- Move the gpg python bindings out of the egg directory.
* Mon Nov 18 2024 Christophe Marin <christophe@krop.fr>
- Fix file list on Leap 15
* Wed Nov 13 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 1.24.0:
  * Extended gpgme_op_decrypt* and gpgme_op_verify* to allow writing the
    output directly to a file. [T6550]
  * Extended gpgme_op_encrypt*, gpgme_op_encrypt_sign*, and gpgme_op_sign*
    to allow reading the input data directly from a file. [T6550]
  * Add information about designated revocation keys. [T7118]
  * New context flag "import-options". [T7152]
  * New context flag "proc-all-sigs". [T7261]
  * New context flag "known-notations". [T4060]
  * New info flags "beta_compliance". [rM1a7bc88ee7]
  * New function gpgme_op_setownertrust to make changing the owner trust
    easier and to allow enabling/disabling of keys (requires GnuPG 2.4.6). [T7239]
  * New flag to re-encrypt OpenPGP data (requires GnuPG 2.5.1). [T1825]
  * cpp: Provide information about designated revocation keys for a Key. [T7118]
  * cpp: Add safer member function returning text describing an error. [T5960]
  * cpp: Add support for setting the owner trust of keys and for enabling
    and disabling keys. [T7239]
  * qt: Build QGpgME for Qt 5 and Qt 6 simultaneously. [T7205]
  * qt: Install headers for Qt 5 and Qt 6 in separate folders. [T7161]
  * qt: Allow reading the data to decrypt/encrypt/sign/verify directly from
    files. [T6550]
  * qt: Allow writing the decrypted/encrypted/signed/verified data directly
    to files. [T6550]
  * qt: Allow specifying import options when importing keys. [T7152]
  * qt: Allow appending a detached signature to an existing file. [T6867]
  * qt: Add support for enabling and disabling keys. [T7239]
  * qt: Add support for new context flag "proc-all-sigs" to the jobs that
    verify data signatures.
  * Interface changes relative to the 1.23.2 release:
  - GPGME_ENCRYPT_FILE                      NEW.
  - GPGME_SIG_MODE_FILE                     NEW.
  - GPGME_ENCRYPT_ADD_RECP                  NEW.
  - GPGME_ENCRYPT_CHG_RECP                  NEW.
  - gpgme_key_t                             EXT: New field 'revkeys'.
  - gpgme_revocation_key_t                  NEW.
  - gpgme_set_ctx_flag                      EXT: New flag 'import-options'.
  - gpgme_set_ctx_flag                      EXT: New flag 'proc-all-sigs'.
  - gpgme_set_ctx_flag                      EXT: New flag 'known-notation'.
  - gpgme_op_setownertrust_start            NEW.
  - gpgme_op_setownertrust                  NEW.
  - gpgme_subkey_t                          EXT: New field 'beta_compliance'.
  - gpgme_signature_t                       EXT: New field 'beta_compliance'.
  - gpgme_decrypt_result_t                  EXT: New field 'beta_compliance'.
  - cpp: Context::EncryptFile               NEW.
  - cpp: Context::setOwnerTrust             NEW.
  - cpp: Context::startSetOwnerTrust        NEW.
  - cpp: Context::setKeyEnabled             NEW.
  - cpp: Context::startSetKeyEnabled        NEW.
  - cpp: SignatureMode::SignFile            NEW.
  - cpp: RevocationKey                      NEW.
  - cpp: Key::revocationKey                 NEW.
  - cpp: Key::numRevocationKeys             NEW.
  - cpp: Key::revocationKeys                NEW.
  - cpp: Key::isBetaCompliance              NEW.
  - cpp: Subkey::isBetaCompliance           NEW.
  - cpp: Error::asStdString                 NEW.
  - cpp: Error::asString                    DEPRECATED.
  - cpp: DecryptionResult::isBetaCompliance NEW.
  - cpp: Signature::isBetaCompliance        NEW.
  - qt: DecryptVerifyArchiveJob::setProcessAllSignatures NEW.
  - qt: DecryptVerifyArchiveJob::processAllSignatures    NEW.
  - qt: DecryptVerifyJob::setInputFile      NEW.
  - qt: DecryptVerifyJob::inputFile         NEW.
  - qt: DecryptVerifyJob::setOutputFile     NEW.
  - qt: DecryptVerifyJob::outputFile        NEW.
  - qt: DecryptVerifyJob::setProcessAllSignatures NEW.
  - qt: DecryptVerifyJob::processAllSignatures    NEW.
  - qt: EncryptJob::setRecipients           NEW.
  - qt: EncryptJob::recipients              NEW.
  - qt: EncryptJob::setInputFile            NEW.
  - qt: EncryptJob::inputFile               NEW.
  - qt: EncryptJob::setOutputFile           NEW.
  - qt: EncryptJob::outputFile              NEW.
  - qt: EncryptJob::setEncryptionFlags      NEW.
  - qt: EncryptJob::encryptionFlags         NEW.
  - qt: SignEncryptJob::setSigners          NEW.
  - qt: SignEncryptJob::signers             NEW.
  - qt: SignEncryptJob::setRecipients       NEW.
  - qt: SignEncryptJob::recipients          NEW.
  - qt: SignEncryptJob::setInputFile        NEW.
  - qt: SignEncryptJob::inputFile           NEW.
  - qt: SignEncryptJob::setOutputFile       NEW.
  - qt: SignEncryptJob::outputFile          NEW.
  - qt: SignEncryptJob::setEncryptionFlags  NEW.
  - qt: SignEncryptJob::encryptionFlags     NEW.
  - qt: SignJob::setSigners                 NEW.
  - qt: SignJob::signers                    NEW.
  - qt: SignJob::setInputFile               NEW.
  - qt: SignJob::inputFile                  NEW.
  - qt: SignJob::setOutputFile              NEW.
  - qt: SignJob::outputFile                 NEW.
  - qt: SignJob::setSigningFlags            NEW.
  - qt: SignJob::signingFlags               NEW.
  - qt: SignJob::setAppendSignature         NEW.
  - qt: SignJob::appendSignatureEnabled     NEW.
  - qt: VerifyDetachedJob::setSignatureFile NEW.
  - qt: VerifyDetachedJob::signatureFile    NEW.
  - qt: VerifyDetachedJob::setSignedFile    NEW.
  - qt: VerifyDetachedJob::signedFile       NEW.
  - qt: VerifyDetachedJob::setProcessAllSignatures NEW.
  - qt: VerifyDetachedJob::processAllSignatures    NEW.
  - qt: VerifyOpaqueJob::setInputFile       NEW.
  - qt: VerifyOpaqueJob::inputFile          NEW.
  - qt: VerifyOpaqueJob::setOutputFile      NEW.
  - qt: VerifyOpaqueJob::outputFile         NEW.
  - qt: VerifyOpaqueJob::setProcessAllSignatures NEW.
  - qt: VerifyOpaqueJob::processAllSignatures    NEW.
  - qt: ImportJob::setImportOptions         NEW.
  - qt: ImportJob::importOptions            NEW.
  - qt: QuickJob::startSetKeyEnabled        NEW.
  * Release-info: https://dev.gnupg.org/T7376
  * Rebase gpgme-suse-nobetasuffix.patch python313.patch
  * Remove patch upstream: gpgme-D545-obsolete-distutils.patch
* Sun Sep  1 2024 Dirk Müller <dmueller@suse.com>
- add python313.patch to enable python 3.13 building
* Sat Feb 17 2024 Ben Greiner <code@bnavigator.de>
- Update gpgme-D545-obsolete-distutils.patch with upstream's
  changes (but use pip instead of python-build for wheel building)
- Change from in-place build to out-of-place build in order to
  reflect upstream's build setup (See D545)
- Don't replace distutils in 15.X
* Sat Jan  6 2024 Ben Greiner <code@bnavigator.de>
- Python 3.12 has dropped distutils
  * Build require python-setuptools instead
  * Drop old gpgme-D545-python310.patch
  * Replace with gpgme-D545-obsolete-distutils.patch
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Make libgpgmepp-devel provide its CMake target file
* Wed Nov 29 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 1.23.2:
  * Preserve more specific existing failure code.  [T6575]
  * qt: Start dirmngr with gpgconf to avoid multiple instances. [T6833]
  * qt: On Windows, use UTF-8 when logging the error text.  [T5960]
  * qt: Remove left-over partial files more persistently.  [T6584]
  * qt: Use a temporary file name when creating signed or encrypted
    archives. [T6721]
  * qt: Build Qt 6 bindings with -fPIC if requested or Qt 6 was built
    with this flag. [T6781]
  * Notes:
  - qt: DefaultKeyGenerationJob     DEPRECATED.
  * Release-info: https://dev.gnupg.org/T6782
* Mon Oct 30 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.23.1:
  * fixes for other platforms
* Wed Oct 25 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 1.23.0:
  * Support GPGME_ENCRYPT_ALWAYS_TRUST also for S/MIME. [T6559]
  * New keylist mode GPGME_KEYLIST_MODE_WITH_V5FPR. [T6705]
  * New key capability flags has_*. [T6748]
  * gpgme-tool: Support use of Windows HANDLE. [T6634]
  * qt: Support refreshing keys via WKD. [T6672]
  * qt: Handle cancel in changeexpiryjob. [T6754]
  * Remove patches fixed upstream:
  - gpgme-qt-tests-Fix-build-in-source-directory.patch
  - gpgme-build-Suggest-out-of-source-build.patch
* Sat Sep 23 2023 Christophe Marin <christophe@krop.fr>
- Use GCC 12 for building the Qt6 library on Leap 15. The
  default compiler is too old.
- Use '%%{without xxx}' rather than '!%%{with xxx}' in spec file
* Sat Sep 23 2023 Christophe Marin <christophe@krop.fr>
- Use GCC 12 for building the Qt6 library. The default compiler
  is too old.
- Use '%%{without xxx}' rather than '!%%{with xxx}' in spec file
* Tue Aug 22 2023 Pedro Monreal <pmonreal@suse.com>
- Fix builds with qt and qt6 [T6673]:
  * qt,tests: Fix build in source directory. Include Qt binding
    sources before C++ binding sources and C sources. This fixes
    the problem that the debug.h in the C sources was found before
    the one in the Qt bindings.
  * build: Suggest out-of-source build. Suggest to run configure
    from a build subdirectory.
  * Add patches:
  - gpgme-qt-tests-Fix-build-in-source-directory.patch
  - gpgme-build-Suggest-out-of-source-build.patch
* Tue Aug 22 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 1.22.0:
  * Prevent wrong plaintext when verifying clearsigned signature.
  * Return bad data error instead of general error on unexpected data.
  * Take care of offline mode for all operations of gpgsm engine.
  * Prepare the use of the forthcoming libassuan version 3.
  * New configure option --with-libtool-modification.
  * cpp: Expose gpgme_decrypt_result_t.is_mime.
  * qt: Clean up after failure or cancel of sign/encrypt archive operation.
  * qt: Add setInputEncoding to QGpgMe::EncryptJob.
  * qt: Make toLogString helper public.
  * Interface changes relative to the 1.21.0 release:
  - qt: EncryptJob::setInputEncoding           NEW.
  - qt: DecryptionResult::isMime               NEW.
  - qt: toLogString                            NEW.
* Thu Aug  3 2023 Andreas Schwab <schwab@suse.de>
- Run testsuite in qemu build
* Mon Jul 10 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 1.21.0
  * Extended gpgme_op_encrypt, gpgme_op_encrypt_sign, and gpgme_op_sign
    to allow writing the output directly to a file. [T6530]
  * Extended gpgme_op_decrypt and gpgme_op_verify to allow reading the
    input data directly from files. [T6530]
  * For key signing and uid revoking allow an empty user id. [rMfbc3963d62]
  * Pass an input-size-hint also to the gpgsm engine. [T6534]
  * qt: Allow writing the created archives directly to a file. [T6530]
  * qt: Allow reading the signed/encrypted archive to decrypt
    or verify directly from a file. [T6530]
  * qt: Qt Jobs working with QIODeviceDataProvider now properly
    handle input-size hints and progress for files larger.
    2^32 bytes in 32 bit builds. [T6534]
  * cpp: Error::isCanceled now also returns true for error code
    GPG_ERR_FULLY_CANCELED. [T6510]
  * python: Fix wrong use of write. [T6501]
  * Interface changes relative to the 1.20.0 release:
  - cpp: Data::setFlag                            NEW.
  - cpp: Data::setSizeHint                        NEW.
  - qt: Job::startIt                              NEW.
  - qt: DecryptVerifyArchiveJob::setInputFile     NEW.
  - qt: DecryptVerifyArchiveJob::inputFile        NEW.
  - qt: EncryptArchiveJob::setRecipients          NEW.
  - qt: EncryptArchiveJob::recipients             NEW.
  - qt: EncryptArchiveJob::setInputPaths          NEW.
  - qt: EncryptArchiveJob::inputPaths             NEW.
  - qt: EncryptArchiveJob::setOutputFile          NEW.
  - qt: EncryptArchiveJob::outputFile             NEW.
  - qt: EncryptArchiveJob::setEncryptionFlags     NEW.
  - qt: EncryptArchiveJob::encryptionFlags        NEW.
  - qt: SignArchiveJob::setSigners                NEW.
  - qt: SignArchiveJob::signers                   NEW.
  - qt: SignArchiveJob::setInputPaths             NEW.
  - qt: SignArchiveJob::inputPaths                NEW.
  - qt: SignArchiveJob::setOutputFile             NEW.
  - qt: SignArchiveJob::outputFile                NEW.
  - qt: SignEncryptArchiveJob::setSigners         NEW.
  - qt: SignEncryptArchiveJob::signers            NEW.
  - qt: SignEncryptArchiveJob::setRecipients      NEW.
  - qt: SignEncryptArchiveJob::recipients         NEW.
  - qt: SignEncryptArchiveJob::setInputPaths      NEW.
  - qt: SignEncryptArchiveJob::inputPaths         NEW.
  - qt: SignEncryptArchiveJob::setOutputFile      NEW.
  - qt: SignEncryptArchiveJob::outputFile         NEW.
  - qt: SignEncryptArchiveJob::setEncryptionFlags NEW.
  - qt: SignEncryptArchiveJob::encryptionFlags    NEW.
* Fri Apr 21 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 1.20.0:
  * On Windows, the gettext functions provided by gpgrt are switched
    into utf8 mode, so that all localized texts returned by GpgME or
    gpgrt, e.g. the texts for error codes are now UTF-8 encoded. [T5960]
  * Key::canSign now returns false for OpenPGP keys without signing
    (sub)key. [T6456]
  * The new macOS Homebrew location is now by default supported. [T6440]
  * Fix regression in 1.19.0.
  * Fix invocation of gpgtar on Windows.
  * Interface changes relative to the 1.19.0 release:
  - gpgme_subkey_t              EXTENDED: New field 'can_renc'.
  - gpgme_subkey_t              EXTENDED: New field 'can_timestamp'.
  - gpgme_subkey_t              EXTENDED: New field 'is_group_owned'.
  - cpp: Subkey::canRenc        NEW.
  - cpp: Subkey::canTimestamp   NEW.
  - cpp: Subkey::isGroupOwned   NEW.
  - cpp: Key::canReallySign     DEPRECATED.
  * Release-info: https://dev.gnupg.org/T6463
* Tue Apr 11 2023 Christophe Marin <christophe@krop.fr>
- Add a Qt6 flavor to build Qt6 bindings
- Use %%ldconfig_scriptlets
* Mon Mar 20 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 1.19.0:
  * New context flag "no-auto-check-trustdb". [T6261]
  * Optionally, build QGpgME for Qt 6
  * Support component "gpgtar-name" in gpgme_get_dirinfo. [T6342]
  * Extended gpgme_op_encrypt*, gpgme_op_encrypt_sign*, and
    gpgme_op_sign* to allow creating an encrypted and/or signed
    archive. [T6342]
  * Extended gpgme_op_decrypt*, gpgme_op_decrypt_verify*,
    and gpgme_op_verify* to allow extracting an encrypted and/or
    signed archive. [T6342]
  * cpp: Handle error when trying to sign expired keys. [T6155]
  * cpp: Support encryption flags ThrowKeyIds, EncryptWrap, and
    WantAddress. [T6359]
  * cpp, qt: Fix building with C++11.  [T6141]
  * qt: Fix problem with expiration dates after 2038-01-19 on 32-bit
    systems  when adding an existing subkey to another key. [T6137]
  * cpp: Allow setting the curve to use when generating ECC keys
    for smart cards. [T4429]
  * qt: Extend ListAllKeysJob to allow disabling the automatic
    trust database check when listing all keys. [T6261]
  * qt: Allow deferred start of import jobs. [T6323]
  * qt: Support creating and extracting signed and encrypted
    archives. [T6342]
  * Rebase gpgme-suse-nobetasuffix.patch
  * Remove patches upstream:
  - gpgme-D546-python310.patch
  - gpgme-1.18.0-T6137-qt_test.patch
  - python311.patch
* Fri Mar 10 2023 Dirk Müller <dmueller@suse.com>
- drop python2 subpackage handling. we do not support python 2.x
  anymore, and if we would it would happen via singlespec
* Mon Jan 23 2023 Pedro Monreal <pmonreal@suse.com>
- Update upstream keyring: https://gnupg.org/signature_key.asc
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- add python311.patch to build language bindings for python 3.11
* Tue Nov  8 2022 Ben Greiner <code@bnavigator.de>
- Add gpgme-suse-nobetasuffix.patch
  * remove "-unknown" suffix from version string
  * boo#1205197
* Thu Aug 18 2022 Andreas Stieger <andreas.stieger@gmx.de>
- gpgme 1.18.0
  * New keylist mode to force refresh via external methods
  * The keylist operations now create an import result to report the
    result of the locate keylist modes
  * core: Return BAD_PASSPHRASE error code on symmetric decryption
    failure
  * cpp, qt: Do not export internal symbols anymore
  * cpp, qt: Support revocation of own OpenPGP keys
  * qt: The file name of (signed and) encrypted data can now be set
  * cpp, qt: Support setting the primary user ID
  * python: Fix segv(NULL) when inspecting contect after exeception
- includes changes from version 1.17.1:
  * qt: Fix a bug in the ABI compatibility of 1.17.0
- includes changes from 1.17.0:
  * New context flag "key-origin"
  * New context flag "import-filter"
  * New export mode to export secret subkeys
  * Detect errors during the export of secret keys
  * New function gpgme_op_receive_keys to import keys from a keyserver
    without first running a key listing
  * Detect bad passphrase error in certificate import
  * Allow setting --key-origin when importing keys
  * Support components "keyboxd", "gpg-agent", "scdaemon", "dirmngr",
    "pinentry", and "socketdir" in gpgme_get_dirinfo
  * Under Unix use poll(2) instead of select(2), when available.
  * Fix results returned by gpgme_data_* functions
  * Support closefrom also for glibc
    (drop upstream gpgme-use-glibc-closefrom.patch
  * cpp,qt: Add support for export of secret keys and secret subkeys.
  * cpp,qt: Support for adding existing subkeys to other keys
  * qt: Extend ChangeExpiryJob to change expiration of primary key
    and of subkeys at the same time
  * qt: Support WKD lookup without implicit import
  * qt: Allow specifying an import filter when importing keys
  * qt: Allow retrieving the default value of a config entry
- drop patches included upstream
  * gpgme-1.16.0-Use-after-free-in-t-edit-sign-test.patch
  * gpgme-1.16.0-t-various-testSignKeyWithExpiration-32-bit.patch
- add patches to fix tests:
  * gpgme-1.18.0-T6137-qt_test.patch
* Fri Dec 24 2021 Ben Greiner <code@bnavigator.de>
- Add patches to support building bindings packages for
  Python 3.10
  * gpgme-D545-python310.patch -- https://dev.gnupg.org/D545
  * gpgme-D546-python310.patch -- https://dev.gnupg.org/D546
* Thu Aug  5 2021 Pedro Monreal <pmonreal@suse.com>
- Fix build with glibc 2.34: [bsc#1189089]
  * Use glibc's closefrom.
  * Add gpgme-use-glibc-closefrom.patch
* Wed Jul  7 2021 Andreas Stieger <andreas.stieger@gmx.de>
- gpgme 1.16.0:
  * New context flag "cert-expire"
  * New data flags "io-buffer-size" and "sensitive"
  * cpp,qt: Add support for trust signatures
  * qt: Add support for flags in LDAP server options
  * qt: Fix too high memory consumption due to QProcess
  * qt: Do not set empty base DN as query of keyserver URL
  * qt: Extend SignKeyJob to create signatures with expiration date
  * python: New optional parameter filter_signatures for decrypt
- run all tests again
- add patches to fix tests:
  * gpgme-1.16.0-Use-after-free-in-t-edit-sign-test.patch
  * gpgme-1.16.0-t-various-testSignKeyWithExpiration-32-bit.patch
* Thu Mar 25 2021 Ben Greiner <code@bnavigator.de>
- Can't assume non-existence of python38 macros in Leap.
  gh#openSUSE/python-rpm-macros#107
  Test for suse_version instead. Only Tumbleweed has and needs the
  python_subpackage_only support.
* Tue Jan 12 2021 Andreas Stieger <andreas.stieger@gmx.de>
- gpgme 1.15.1:
  * Fix a bug in the secret key export
  * Make listing of signatures work if only secret keys are listed
  * qt: Avoid empty "rem@gnupg.org" signature notations
  * python: Fix key_export functions
- remove deprecated texinfo macros
* Sat Dec  5 2020 Benjamin Greiner <code@bnavigator.de>
- Use python-rpm-macros to provide python3X-gpg for all present
  python3 flavors -- gh#openSUSE/python-rpm-macros#66
* Tue Nov 17 2020 Andreas Stieger <andreas.stieger@gmx.de>
- gpgme 1.15.0:
  * New function gpgme_op_setexpire to make changing the expiration
    easier
  * New function gpgme_op_revsig to revoke key signatures
  * Support exporting secret keys
  * cpp: Support for set expire operations in the C++ bindings
  * cpp: Support for revoking key signatures in the C++ bindings
  * qt: Extended ChangeExpiryJob to support changing the expiry of
    subkeys
  * qt: Extended QuickJob to support revoking of key signatures
  * qt: Added QDebug stream operator for GpgME::Error.
  * Require libgpg-error 1.36
* Fri Jul 17 2020 Andreas Stieger <andreas.stieger@gmx.de>
- gpgme 1.14.0:
  * New keylist mode to force the engine to return the keygrip
  * New export mode to export as OpenSSH public key
  * New context flag "extended-edit" to enable expert key edit
  * Deprecate the anyway non working trustlist functions
  * cpp: Add convenience API to obtain remarks
  * cpp: The sign key edit-interactor now supports multiple
    signatures from the same key
  * qt: Extended signkeyjob to handle remarks and multiple
    signatures
  * qt: Added job API for gpg-card
  * qt: The logging category has been changed to gpg.qgpgme to be
    more consistent with other qt logging categories
- drop upstream patches:
  * 0001-gpg-Avoid-error-diagnostics-with-override-session-ke.patch
- drop patches no longer needed that now break tests:
  * gpgme-t-json-test-Bravo-key-no-secret-key-material.patch
  * gpgme-t-json-test-with-keygrip-when-listing-keys.patch
* Thu Jul  2 2020 Dan Čermák <dcermak@suse.com>
- Add 0001-gpg-Avoid-error-diagnostics-with-override-session-ke.patch
  This patch is a fix from
  https://dev.gnupg.org/rMae4d7761a15b82eb98b0bcc72af2ae2e8973e1f9 which fixes
  https://dev.gnupg.org/T3464
  The patch is required to make notmuch's testsuite pass with gpgme 1.13.0 and
  1.13.1. For further details, see id:87366av72u.fsf@fifthhorseman.net on
  notmuch@notmuchmail.org
* Thu May 14 2020 Matej Cepl <mcepl@suse.com>
- Don't delete python egg-info files (bsc#1168795)
* Wed Apr 29 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Fix build: [bsc#1170811]
  * Test t-json fails since the gpg-2.2.20 update
- Add patches:
  * gpgme-t-json-test-Bravo-key-no-secret-key-material.patch
  * gpgme-t-json-test-with-keygrip-when-listing-keys.patch
* Wed Oct 16 2019 Michael Gorse <mgorse@suse.com>
- Build qt bindings separately to avoid build cycle with
  samba/libsoup.
* Fri Jun 14 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- gpgme 1.13.1:
  * core: At debug levels up to 9 print only an ascii dump.
  * core: Add commented debug helper to posix-io.c.
  * core: Fix error return value of _gpgme_run_io_cb.
  * core: Prettify _gpgme_io_select debug output again and fix TRACE_SYSRES.
  * core: Improve the debug messages even more.
  * core: Avoid explicit locks in the debug code.
  * json: Print "nan", "-inf", "inf" if needed.
  * json: Improve handling of large exponents in the JSON parsor.
  * core: Implement recpstring option parsing for gpgsm.
  * core: Make gpgme_op_encrypt_ext work for CMS.
  * python: Fix typo in DecryptionError exception.
  * python: Make EXTRA_DIST files explicit.
  * Python, doc: Minor style improvement.
  * Always use maintainer mode -Wno cflags.
  * cpp: Fix initialization warning.
  * python: stop raising BadSignatures from decrypt(verify=True)
  * cpp: Add wrapper for gpgme_set_global_flag.
  * core: Fix duplication of close_notify_handler for gpgsm.
* Sun Mar 31 2019 Andreas Stieger <andreas.stieger@gmx.de>
- gpgme 1.13.0:
  * Support GPGME_AUDITLOG_DIAG for gpgsm
  * New context flag "trust-model".
  * Aligned the gpgrt-config code with our other libaries
  * Auto-check for all installed Python versions
  * Fixed generating card key in the C++ bindings
  * Fixed a segv due to bad parameters in genkey
  * Fixed crash if the plaintext is ignored in a CMS verify
  * Fixed test suite problems related to dtags
  * Fixed bunch of python bugs
  * Several fixes to the Common Lisp bindings
  * Fixed minor bugs in gpgme-json
  * Require trace level 8 to dump all I/O data
  * The compiler must now support variadic macros
- drop gpgme-key-expirity.patch, included upstream
* Wed Jan  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Regen keys in Qt tests to not expire bsc#1121051:
  * gpgme-key-expirity.patch
* Tue Oct  9 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix the build on ix86 as we disable one test there that should
  not work, sadly just sed is employed as the infrastructure for
  testing is not smart enough for comfy test filtering
* Mon Oct  8 2018 Karol Babioch <kbabioch@suse.com>
- Update to 1.12.0:
  * Enhanced the JSON based interface tool gpgme-json to support Native
  Messaging as well as new Javascript code to support the browser
  site.  See lang/js/README for details.
  * Major overhaul of the Python language bindings documentation
  * Even for old versions of gpg a missing MDC will now lead to a
  decryption failure
  * Added context flag "auto-key-locate" to control the
  behavior of GPGME_KEYLIST_MODE_LOCATE
  * New data function to create a data object from an estream
  * Add more interfaces to the C++ binding
  * Improved error codes on decryption failure
  * Lots of minor fixes
  * Interface changes
* Fri Apr 20 2018 astieger@suse.com
- update to 1.11.1:
  * Fixed build problems in the 1.11.0 releas
    drop gpgme-1.11-fix-gpgme-json-rpath.patch,
    drop gpgme-1.11-fix-tests.patch
  * Added C++ interfaces which were planned for 1.11.0
* Thu Apr 19 2018 kbabioch@suse.com
- Update to 1.11
  * New encryption API to support direct key specification including
  hidden recipients option and taking keys from a file.  This also
  allows to enforce the use of a subkey.
  * New encryption flag for the new API to enforce the use of plain
  mail addresses (addr-spec).
  * The import API can now tell whether v3 keys are skipped. These
  old and basically broken keys are not anymore supported by GnuPG
  2.1.
  * The decrypt and verify API will now return the MIME flag as
  specified by RFC-4880bis.
  * The offline mode now has an effect on gpg by disabling all
  network access.
  * A failed OpenPGP verification how returns the fingerprint of the
  intended key if a recent gpg version was used for signature
  creation.
  * Various minor fixes.
- Dropped patch 0001-core-Tweak-STATUS_FAILURE-handling.patch, since
  it is included upstream now.
- add gpgme-1.11-fix-gpgme-json-rpath.patch to remove rpath
- add gpgme-1.11-fix-tests.patch to fix tests
* Mon Apr 16 2018 astieger@suse.com
- bsc#1089497: Address failure handling issues when using gpg 2.2.6
  via gpgme, as used by libzypp
  Add 0001-core-Tweak-STATUS_FAILURE-handling.patch
* Mon Jan  8 2018 tchvatal@suse.com
- Tweak up the python conditional to allow us finegraining and
  selecting only py2 or py3 if needed
* Tue Dec 12 2017 astieger@suse.com
- gpgme 1.10.0:
  * Now returns more specific error codes for decryption to distinguish
    between bad passphrase, user canceled, and no secret key.
  * Now returns key origin information if available.
  * Added context flag "auto-key-retrieve" to selectively enable the
    corresponding gpg option.
  * Added flag is_de_vs to decryption and verify results.
  * py: Use SEEK_SET as default for data.seek.
  * cpp: Various new APIs.
  * Reduced spawn overhead on Linux again.  Added new configure option
  - -disable-linux-getdents to disable this feature for very old
    Linux versions.
  * Improved the Python bindings build system.
  * Made the test suite less fragile.
  * Interface changes relative to the 1.9.0 release:
    gpgme_decrypt_result_t      EXTENDED: New field 'is_de_vs'.
    gpgme_signature_t           EXTENDED: New field 'is_de_vs'.
    gpgme_keyorg_t              NEW.
    gpgme_op_delete_ext         NEW.
    gpgme_op_delete_ext_start   NEW.
    GPGME_DELETE_ALLOW_SECRET   NEW.
    GPGME_DELETE_FORCE          NEW.
    gpgme_op_conf_dir           NEW.
    gpgme_set_ctx_flag          EXTENDED: New flag 'auto-key-retrieve'.
    cpp: DecryptionResult::isDeVs         NEW.
    cpp: Signature::isDeVs                NEW.
    cpp: EngineInfo::Version::operator>   NEW.
    cpp: Context::createKey               NEW.
    cpp: Context::startCreateKey          NEW.
    cpp: Context::createSubkey            NEW.
    cpp: Context::startCreateSubkey       NEW.
    qt: QuickJob                          NEW.
    py: DecryptResult           EXTENDED: New boolean field 'is_de_vs'.
    py: Signature               EXTENDED: New boolean field 'is_de_vs'.
    py: GpgError                EXTENDED: Partial results in 'results'.
* Tue Nov  7 2017 mpluskal@suse.com
- Make python package naming consistent with python singlespec
* Tue Mar 28 2017 astieger@suse.com
- gpgme 1.9.0:
  * Clarified meaning of the 'expire' parameter of gpgme_op_createkey
  and gpgme_op_createsubkey.  New flag to force a key without an
  expiration date.
  * New function gpgme_op_keylist_from_data_start to list keys from
  data objects without importing them.
  * New function gpgme_op_set_uid_flag to flag a key as primary.
  * New function gpgme_op_decrypt_ext to run decryption with special
  flags.  This can for example be used to unwrap keys (remove only
  the encryption layer).
  * New encryption flags to wrap a key (adding an encryption layer to
  an OpenPGP message) or to create anonymously encrypted messages.
  * Support for adduid and revuid operations in the C++ bindings.
  * Support for smartcard key generation in the C++ bindings.
  * Several new functions for the Python binding.
  * Many smaller bug fixes.
  * Interface changes relative to the 1.8.0 release:
  gpgme_op_createkey          CHANGED: Meaning of 'expire' parameter.
  gpgme_op_createsubkey       CHANGED: Meaning of 'expire' parameter.
  GPGME_CREATE_NOEXPIRE       NEW.
  gpgme_key_t                 EXTENDED: New field 'origin'.
  gpgme_key_t                 EXTENDED: New field 'last_update'.
  gpgme_subkey_t              EXTENDED: New field 'is_de_vs'.
  gpgme_user_id_t             EXTENDED: New field 'origin'.
  gpgme_user_id_t             EXTENDED: New field 'last_update'.
  gpgme_op_keylist_from_data_start NEW.
  gpgme_op_set_uid_flag_start      NEW.
  gpgme_op_set_uid_flag            NEW.
  gpgme_op_decrypt_ext_start       NEW.
  gpgme_op_decrypt_ext             NEW.
  GPGME_ENCRYPT_THROW_KEYIDS       NEW.
  GPGME_ENCRYPT_WRAP               NEW.
  GPGME_DECRYPT_VERIFY             NEW.
  GPGME_DECRYPT_UNWRAP             NEW.
  gpgme_data_rewind                UN-DEPRECATE.
  cpp: Context::revUid(const Key&, const char*)      NEW.
  cpp: Context::startRevUid(const Key&, const char*) NEW.
  cpp: Context::addUid(const Key&, const char*)      NEW.
  cpp: Context::startAddUid(const Key&, const char*) NEW.
  cpp: Key::UserID::revoke()                         NEW.
  cpp: Key::addUid()                                 NEW.
  cpp: Key::isDeVs                                   NEW.
  cpp: GpgGenCardKeyInteractor                       NEW.
  cpp: Subkey::keyGrip                               NEW.
  cpp: Subkey::isDeVs                                NEW.
  cpp: Data::toKeys                                  NEW.
  cpp: Context::setDecryptFlags                      NEW.
  cpp: Context::decrypt                         EXTENDED: Flags added.
  cpp: Context::startDecrypt                    EXTENDED: Flags added.
  cpp: Context::decryptAndVerify                EXTENDED: Flags added.
  cpp: Context::startCombinedDecryptionAndVerification EXTENDED: Flags.
  cpp: Context::encryptFlags                    EXTENDED: New flags.
  qt: CryptoConfig::stringValueList()                NEW.
  py: Context.__init__        EXTENDED: New keyword arg home_dir.
  py: Context.home_dir        NEW.
  py: Context.keylist         EXTENDED: New keyword arg mode.
  py: Context.keylist         EXTENDED: New keyword arg source.
  py: Context.create_key      NEW.
  py: Context.create_subkey   NEW.
  py: Context.key_add_uid     NEW.
  py: Context.key_revoke_uid  NEW.
  py: Context.key_sign        NEW.
  py: Context.key_tofu_policy NEW.
  py: core.pubkey_algo_string NEW.
  py: core.addrspec_from_uid  NEW.
- drop upstreamed patches:
  * gpgme-include_functional.patch
  * remove-a-forgotten-instance-of-libsuffix.diff
* Thu Mar 23 2017 lbeltrame@kde.org
- Re-conditionalize python builds, to allow gpgme to build on
  Leap 42.3 (python tests fail with an older gpg, see
  gpg issue 3008)
- Enable Qt build also on Leap 42.3 (needed for KDE PIM)
* Tue Feb 14 2017 tchvatal@suse.com
- Unconditionalize python and python3 builds
- Unconditionalize c++ build
* Mon Feb 13 2017 jengelh@inai.de
- Fix RPM groups
* Mon Feb 13 2017 tchvatal@suse.com
- Do not condition around the qt version as it breaks baselibs validator
* Tue Feb  7 2017 crrodriguez@opensuse.org
- gpgme-include_functional.patch: include <functional> where
  needed, fix GCC7 build
* Tue Nov 22 2016 lbeltrame@kde.org
- Add remove-a-forgotten-instance-of-libsuffix.diff: fix CMake
  files for gpgmepp (or they won't work with KDE software)
* Sat Nov 19 2016 astieger@suse.com
- gpgme 1.8:
  * The module of the Python bindings has been renamed to 'gpg'.
  * New interface to query current software versions.
  * New feature to use gpg's --{show,override}session-key options.
  * New interface to set the sender of a mail.
  * qt: Added Distinguished Name parser from libkleo
  * The --homedir option is now used with recent gpgconf versions.
  * The internal locking functions have been replaced by libgpg-error
    locking functions.
  * Interface changes relative to the 1.7.1 release:
    gpgme_set_sender                NEW.
    gpgme_get_sender                NEW.
    gpgme_op_query_swdb             NEW.
    gpgme_op_query_swdb_result      NEW.
    gpgme_query_swdb_result_t       NEW.
    gpgme_get_ctx_flag              NEW.
    gpgme_decrypt_result_t          EXTENDED: New field session_key.
    qt: DN                          NEW.
    qt: DN::Attribute               NEW.
    qt: Job::context(Job*)          NEW.
    cpp: EngineInfo::Version::Version(const char*) NEW.
    cpp: EngineInfo::Version::Version()            NEW.
    cpp: SwdbResult                                NEW.
    cpp: Context::setSender(const char*)           NEW.
    cpp: Context::getSender()                      NEW.
* Fri Oct 21 2016 astieger@suse.com
- in addition to dropping gpgme-1.7.0-python-Include-config.h.patch
  remove automake depdendency and autogen.sh call
- build QT lib only on Factory
* Thu Oct 20 2016 jengelh@inai.de
- Trim and update descriptions
* Tue Oct 18 2016 lbeltrame@kde.org
- New upstream release 1.7.1
  * Fixed problems with the new language bindings.
  * New helper function gpgme_addrspec_from_uid.
  * Use option --exit-on-status-write-error with newer gpg versions.
  * qt: Missed API from the Qt Binding inclusion has
    been added again.
  * qt: abstractimportjob.h is now installed to that
    ImportJobs can be used again.
  * qt: Fixed spelling error in API (startReceive).
  * Interface changes relative to the 1.7.0 release:
    gpgme_addrspec_from_uid         NEW.
    qt: WksPublishJob::startRecieve RENAMED to ::startReceive.
    qt: MultiDeleteJob              NEW.
    qt: AbstractImportJob           NEW.
    qt: SpecialJob                  NEW.
    cpp: Signature::key(bool, bool)              NEW.
    cpp: UserID::addrSpecFromString(const char*) NEW.
    cpp: UserID::addrSpec()                      NEW.
- Drop conflict (handled on kdepimlibs4 side)
- Drop upstreamed patches:
  * gpgme-1.7.0-nonvoid-returns.patch
  * gpgme-1.7.0-cpp-qt-Include-config.h.patch
  * gpgme-1.7.0-python-Include-config.h.patch
* Wed Oct 12 2016 lbeltrame@kde.org
- Switch on the Qt bindings
- Add missing buildrequires, files, and needed adjustments for the
  Qt build
* Tue Oct 11 2016 lbeltrame@kde.org
- Conflict libgpgmepp-devel with kdepimlibs4-devel as they both
  install the same header (kdepimlibs4 for historical reasons)
* Mon Sep 26 2016 astieger@suse.com
- gpgme 1.7.0:
  * Python2 bindings
  * C++ bindings
  * disabled: Python3, Qt-Framework API
  * New functions gpgme_op_createkey and gpgme_op_createsubkey to make
    key creation easier (requires GnuPG 2.1).
  * New functions gpgme_op_adduid and gpgme_op_revuid to make user id
    management easier (requires GnuPG 2.1).
  * New function gpgme_op_keysign to make key signing easier (requires
    GnuPG 2.1).
  * New function gpgme_op_interact to replace the now deprecated
    functions gpgme_op_edit and gpgme_op_card_edit.
  * New function gpgme_pubkey_algo_string to convert a public key
    algorithm into a GnuPG 2.1 style string.
  * Support for GnuPG 2.1's TOFU trust model.
  * Notation flags are now correctly set on verify.
  * New global flag "require-gnupg" to set a minimal gnupg version.
  * More supported items in gpgme_get_dirinfo.
  * New function gpgme_data_set_flag and flag "size-hint".
  * New function gpgme_set_ctx_flag and flags "full-status" and
    "raw-description".
  * Improved gpgme_data_identify to distinguish more file types.
  * New flag GPGME_ENCRYPT_SYMMETRIC for gpgme_op_encrypt to allow
    mixed public key and symmetric encryption.
  * New field KEYGRIP in gpgme_subkey_t.  New fields FPR in gpgme_key_t.
  * New flag GPGME_DATA_ENCODING_MIME to declare that the encrypted or
    signed data is a valid MIME part.  This is to support future GnuPG
    versions.
  * Interface changes relative to the 1.6.0 release:
    gpgme_pubkey_algo_string       NEW.
    GPGME_PK_EDDSA                 NEW.
    gpgme_set_ctx_flag             NEW.
    gpgme_data_set_flag            NEW.
    gpgme_op_createkey             NEW.
    gpgme_op_createkey_start       NEW.
    gpgme_op_createsubkey          NEW.
    gpgme_op_createsubkey_start    NEW.
    gpgme_op_adduid_start          NEW.
    gpgme_op_adduid                NEW.
    gpgme_op_revuid_start          NEW.
    gpgme_op_revuid                NEW.
    gpgme_op_keysign_start         NEW.
    gpgme_op_keysign               NEW.
    gpgme_op_tofu_policy_start     NEW.
    gpgme_op_tofu_policy           NEW.
    gpgme_op_interact_start        NEW.
    gpgme_op_interact              NEW.
    gpgme_interact_cb_t            NEW.
    gpgme_op_edit_start            DEPRECATED.
    gpgme_op_edit                  DEPRECATED.
    gpgme_op_card_edit_start       DEPRECATED.
    gpgme_op_card_edit             DEPRECATED.
    gpgme_edit_cb_t                DEPRECATED.
    gpgme_status_code_t            DEPRECATED.
    gpgme_genkey_result_t          EXTENDED: New fields pubkey and seckey.
    gpgme_signature_t              EXTENDED: New field key.
    gpgme_key_t                    EXTENDED: New field fpr.
    gpgme_subkey_t                 EXTENDED: New field keygrip.
    gpgme_user_id_t                EXTENDED: New field tofu.
    gpgme_tofu_policy_t            NEW.
    gpgme_tofu_info_t              NEW.
    GPGME_STATUS_KEY_CONSIDERED    NEW.
    GPGME_STATUS_TOFU_USER         NEW.
    GPGME_STATUS_TOFU_STATS        NEW.
    GPGME_STATUS_TOFU_STATS_LONG   NEW.
    GPGME_STATUS_NOTATION_FLAGS    NEW.
    GPGME_KEYLIST_MODE_WITH_TOFU   NEW.
    GPGME_DATA_TYPE_PGP_ENCRYPTED  NEW.
    GPGME_DATA_TYPE_PGP_SIGNATURE  NEW.
    GPGME_DATA_ENCODING_MIME       NEW.
    GPGME_ENCRYPT_SYMMETRIC        NEW.
    GPGME_CREATE_SIGN              NEW.
    GPGME_CREATE_ENCR              NEW.
    GPGME_CREATE_CERT              NEW.
    GPGME_CREATE_AUTH              NEW.
    GPGME_CREATE_NOPASSWD          NEW.
    GPGME_CREATE_SELFSIGNED        NEW.
    GPGME_CREATE_NOSTORE           NEW.
    GPGME_CREATE_WANTPUB           NEW.
    GPGME_CREATE_WANTSEC           NEW.
    GPGME_CREATE_FORCE             NEW.
    GPGME_KEYSIGN_LOCAL            NEW.
    GPGME_KEYSIGN_LFSEP            NEW.
    GPGME_INTERACT_CARD            NEW.
  * Add patches to fix build:
    + gpgme-1.7.0-nonvoid-returns.patch
    + gpgme-1.7.0-cpp-qt-Include-config.h.patch
    + gpgme-1.7.0-python-Include-config.h.patch
* Fri Sep 11 2015 astieger@suse.com
- restore taking build timestamp from changelog date
* Wed Aug 26 2015 astieger@suse.com
- gpgme 1.6.0:
  * Added gpgme_set_offline to do a key listinging w/o requiring
  CRL.
  * Added gpgme_set_status_cb to allow a user to see some status
  messages.
  * Added an export mode for secret keys.
  * More precise error codes are returned if GnuPG >= 2.1.8 is used.
  * The passphrase handler for the loopback mode has been improved and may
  also be used with genkey.
  * Interface changes relative to the 1.5.1 release:
  gpgme_set_offline              NEW.
  gpgme_get_offline              NEW.
  gpgme_set_status_cb            NEW.
  gpgme_get_status_cb            NEW.
  GPGME_EXPORT_MODE_SECRET       NEW
  GPGME_EXPORT_MODE_RAW          NEW.
  GPGME_EXPORT_MODE_PKCS12       NEW.
* Fri Jun 19 2015 astieger@suse.com
- fix install-info for clean uninstall [boo#935339]
* Mon Jun  8 2015 astieger@suse.com
- gpgme 1.5.5:
  * Fixed crash in key listings for user ids with a backslash.
  * Fixed regression for GPGSM use with GnuPG < 2.1.
  * Properly set signature summary for revoked OpenPGP keys.
* Tue Apr 14 2015 astieger@suse.com
- gpgme 1.5.4:
  * Fixed a possible crash in the debug code.
* Tue Feb  3 2015 coolo@suse.com
- making the build reproducible - see
  http://lists.gnupg.org/pipermail/gnupg-commits/2014-September/010683.html
  for a very similiar problem
* Fri Dec 26 2014 andreas.stieger@gmx.de
- gpgme 1.5.3:
  * The export key functions do now return an error if used with the
  latest GnuPG version.
* Sat Nov 22 2014 andreas.stieger@gmx.de
- gpgme 1.5.2:
  + gpgme-tool is now installed.
  + Fix external listing for modern keyservers.
  + Minor other fixes.
- disable failing unit tests
* Sun Aug  3 2014 andreas.stieger@gmx.de
- gpgme 1.5.1
  - Fixed possible overflow in gpgsm and uiserver engines.
    [bnc#890123] [CVE-2014-3564]
  - Added support for GnuPG 2.1's --with-secret option.
  - Interface changes relative to the 1.5.0 release:
    GPGME_KEYLIST_MODE_WITH_SECRET NEW.
* Wed May 21 2014 andreas.stieger@gmx.de
- gpgme 1.5.0
  - On Unices the engine file names are not not anymore hardwired
    but located via the envvar PATH.  All options to set the name of
    the engines for the configure run are removed.
  - If GPGME finds the gpgconf binary it defaults to using gpg2 or
    whatever gpgconf tells as name for the OpenPGP engine.  If
    gpgconf is not found, GPGME looks for an engine named "gpg".
  - New feature to use the gpgme I/O subsystem to run arbitrary
    commands.
  - New flag to use encryption without the default compression step.
  - New function to access "gpg-conf --list-dirs"
  - New configure option --enable-fixed-path for use by Android.
  - Support ECC algorithms.
  - Interface changes relative to the 1.4.3 release:
    gpgme_get_dirinfo              NEW.
    gpgme_op_spawn_start           NEW.
    gpgme_op_spawn                 NEW.
    GPGME_PROTOCOL_SPAWN           NEW.
    GPGME_SPAWN_DETACHED           NEW.
    GPGME_SPAWN_ALLOW_SET_FG       NEW.
    GPGME_ENCRYPT_NO_COMPRESS      NEW.
    GPGME_PK_ECC                   NEW.
    GPGME_MD_SHA224                NEW.
    gpgme_subkey_t                 EXTENDED: New field curve.
    GPGME_STATUS_PLAINTEXT_LENGTH  NEW.
    GPGME_STATUS_MOUNTPOINT        NEW.
    GPGME_STATUS_PINENTRY_LAUNCHED NEW.
    GPGME_STATUS_ATTRIBUTE         NEW.
    GPGME_STATUS_BEGIN_SIGNING     NEW.
    GPGME_STATUS_KEY_NOT_CREATED   NEW.
* Tue Aug 13 2013 andreas.stieger@gmx.de
- update to 1.4.3:
  * The default engine names are now taken from the output of gpgconf.
    If gpgconf is not found the use of gpg 1 is assumed.
  * New function gpgme_data_identify to detect the type of a message.
  * Interface changes relative to the 1.4.2 release:
    gpgme_signers_count            NEW.
    gpgme_data_type_t              NEW.
    gpgme_data_identify            NEW.
- includes changes from 1.4.2:
  * Allow symmetric encryption with gpgme_op_encrypt_sign.
  * Interface changes relative to the 1.4.1 release:
    gpgme_off_t                    NEW.
    gpgme_size_t                   NEW.
    GPGME_PROTOCOL_OPENPGP         NEW alias.
- includes changes from 1.4.1:
  * Fixed reading of gpg.conf files with excessive use of the group
    option
* Thu May 23 2013 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-3.0+
  See the HACKING file in the doc directory
* Tue Mar 12 2013 andreas.stieger@gmx.de
- gpgme-config --libs lists -lassuan, but libgpgme-devel did not
  require libassuan-devel [bnc#808882]
* Sun Mar  3 2013 andreas.stieger@gmx.de
- update to 1.4.0
  * New function gpgme_io_writen as a convenience wrapper around
  gpgme_io_write.
  * New functions to support the pinentry mode feature of GnuPG 2.1.
  * New macro GPGME_VERSION_NUMBER to allow supporting different API
  versions without the need for a configure test.
  * Several improvements for gpgme-tool.
  * Better logging of the common "invalid engine" error code.
  * Support for FD passing is now enabled by default.  The configure
  option --disable-fd-passing may be used to disable this.
  * Interface changes relative to the 1.3.1 release:
  GPGME_VERSION_NUMBER           NEW.
  gpgme_io_writen                NEW.
  gpgme_set_global_flag          NEW.
  gpgme_set_pinentry_mode        NEW.
  gpgme_get_pinentry_mode        NEW.
  gpgme_pinentry_mode_t          NEW.
  GPGME_PINENTRY_MODE_DEFAULT    NEW.
  GPGME_PINENTRY_MODE_ASK        NEW.
  GPGME_PINENTRY_MODE_CANCEL     NEW.
  GPGME_PINENTRY_MODE_ERROR      NEW.
  GPGME_PINENTRY_MODE_LOOPBACK   NEW.
- pass --disable-fd-passing, regression tests crash otherwise
- add verification of source tarball signatures during build
- remove conflict marker in past changelog entries
- drop gpgme-1.3.2-gpgme-config-remove-extraneous-libs.patch
  other packages in openSUSE:Factory which depend on gpgme also depend
  on libassuan
- autogen call no longer required
- call make in %%build section
* Fri Nov 16 2012 andreas.stieger@gmx.de
- update to 1.3.2
  * Remove support for libgpgme-pth.  As far as we know, this was never used,
  and GnuPG is going to use our own npth in the future.
  * Fix signature summary information for a missing X.509 key.
  * Fix parsing of dates >= year 2038.
- refresh gpgme-1.3.0-gpgme-config-remove-extraneous-libs.patch
  to gpgme-1.3.2-gpgme-config-remove-extraneous-libs.patch
- actual minimum requirement for libgpg-error is >= 1.8
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Oct  2 2011 crrodriguez@opensuse.org
- Workaround qemu-arm bugs
- remove support for the "pth" library, which has not seen
  mainteniance for around 5 years, native pthread support
  should be just fine in linux too.
* Mon Sep  5 2011 vuntz@opensuse.org
- Move gpg2 Requires from gpgme to libgpgme11 since it's the
  library that will call the binary when it needs it.
  Fix bnc#715963.
- Add libgpgme11 Requires to gpgme as this package makes no sense
  without the library.
* Fri Jul 29 2011 puzel@novell.com
- update to gpgme-1.3.1
  - Detect GPG versions not supporting ---passwd.
  - Interface changes relative to the 1.3.0 release:
  GPGME_EXPORT_MODE_MINIMAL     NEW
  GPGME_STATUS_SUCCESS          NEW
  gpgme_err_code_from_syserror  NEW
  gpgme_err_set_errno           NEW
  gpgme_error_from_errno        CHANGED: Return gpgme_error_t
  gpgme_error_from_syserror     NEW
- drop gnupg-2.0.17-test-failure.patch (fixed upstream)
* Thu Apr 28 2011 idoenmez@novell.com
- Add gnupg-2.0.17-test-failure.patch: fix test failure with gnupg 2.0.17
* Fri Feb  4 2011 sbrabec@suse.cz
- Removed unneeded dependency of libgpgme11.
* Mon Jan 31 2011 gber@opensuse.org
- added gpgme-1.3.0-gpgme-config-remove-extraneous-libs.patch in
  order to remove the extraneuos libassuan from gpgme-config
* Tue Dec 14 2010 cristian.rodriguez@opensuse.org
- run spec cleaner
- fix -devel package dependencies
* Wed Apr 14 2010 chris@computersalat.de
- fix deps
  o pth / libpth-devel >= 2.0.7
* Mon Apr  5 2010 aj@suse.de
- Add requires of libassuan-devel on devel package.
* Wed Mar 31 2010 puzel@novell.com
- update to gpgme-1.3
  * GPGME does not come with an internal libassuan version anymore.
  The external libassuan 1.1.0 release or later is required.  For
  application programmers on systems that can resolve inter-library
  dependencies at runtime, this is a transparent change.
  * New engine GPGME_PROTOCOL_G13 to support the new g13 tool.
  * New engine GPGME_PROTOCOL_UISERVER to support UI Servers.
  * New API to change the passpgrase of a key.
  * Interface changes relative to the 1.2.0 release:
  - GPGME_STATUS_INV_SGNR    NEW.
  - GPGME_STATUS_NO_SGNR     NEW.
  - GPGME_PROTOCOL_G13       NEW.
  - gpgme_op_g13_mount       NEW.
  - gpgme_g13_result_t       NEW.
  - GPGME_PK_ECDSA           NEW.
  - GPGME_PK_ECDH            NEW.
  - gpgme_op_passwd_start    NEW.
  - gpgme_op_passwd          NEW.
- drop gpgme-1.1.8-makecheck.patch (not needed)
* Sun Jan 31 2010 jengelh@medozas.de
- package baselibs.conf
* Tue Jun 23 2009 puzel@novell.com
- update to gpgme-1.2.0
  * New encryption flag GPGME_ENCRYPT_NO_ENCRYPT_TO to disable default
  recipients.
  * gpgme_new will fail if gpgme_check_version was not called, or a
  selftest failed (for example, if -mms-bitfields was not used on
  MingW32 targets).
  * New functions gpgme_io_read and gpgme_io_write for use with
  gpgme_passphrase_cb_t and gpgme_edit_cb_t functions.
  * New functions gpgme_result_ref and gpgme_result_unref to detach
  result structures from a context.
  * New functions gpgme_op_export_keys_start and gpgme_op_export_keys
  that allow to specify exported keys through gpgme_key_t objects
  instead of patterns.
  * New mode of operation gpgme_export_mode_t that allows exporting
  external keys.
- drop unneeded BRs: libgcrypt-devel, libksba-devel
* Thu Jun 11 2009 puzel@suse.cz
- change BuildRequires: (pth-devel -> libpth-devel)
* Tue Jun  2 2009 dmueller@suse.de
- fix requires of devel package
* Mon Jun  1 2009 puzel@suse.cz
- BuildRequires: pth-devel
* Wed Feb 18 2009 puzel@suse.cz
- update to 1.1.8
  * SIGPIPE is now again ignored as described in the manual.  Fixes
  regresion introduced with 1.1.6.
* Mon Dec  8 2008 puzel@suse.cz
- update to 1.1.7
  - using GPGME_KEYLIST_MODE_LOCAL combined with
    GPGME_KEYLIST_MODE_EXTERN is now supported
  - the encoding of gpgme_data_t objects can affect the output encoding
    of export, sign and encrypt operations now
  - the reference manual now includes the specification of "The GnuPG
    UI Server protocol"
  - a new function gpgme_cancel_async can be used to asynchronously
    cancel any pending operation at any time, from any thread
- remove gpgme-1.1.6-from-upstream.patch (fixed upstream)
- remove gpgme-1.1.4-warning.patch (fixed upstream)
- fix obsolete usage of run_ldconfig
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Feb  6 2008 bk@suse.de
- update to version 1.1.6: API extensions, eg for gpgconf thru gpgme
- add upstream patches to run the testsuite non-interactively
* Thu Dec 27 2007 crrodriguez@suse.de
- fix library-without-ldconfig-post* errors
- remove "la" files
* Tue Aug  7 2007 ro@suse.de
- remove devel requires from library package
* Mon Aug  6 2007 mrueckert@suse.de
- add defattr to the lib package
* Mon Aug  6 2007 zpetrova@suse.cz
- split gpgme to libgpgme11 and gpgme.
* Fri Jul 27 2007 zpetrova@suse.cz
- update to version 1.1.5
  - small bug and portability fixes.
* Wed May 16 2007 zpetrova@suse.cz
- removed gpg from Requires list. (#273491)
* Mon Mar 12 2007 zpetrova@suse.cz
- updated filelist
* Fri Mar  9 2007 ltinkl@suse.cz
- update to latest version (1.1.4), needed for gpa
  * Detect and bail out on double plaintext messages.  This is required
    so that applications can properly detect the signed parts of a
    message.  Actual there is now a double protection as GnuPG 1.4.7
    will detect this case too.
  * Fixed a memory leak in gpgme_data_release_and_get_mem.
  * Fixed a bug in Windows command line quoting.
* Sun Feb  4 2007 ro@suse.de
- updated filelist
* Wed Sep 20 2006 anosek@suse.cz
- fixed compiler warning: variable "key" is used before its value
  is set [#159104] (warning.patch)
* Mon Jul 17 2006 nadvornik@suse.cz
- fixed pthread support in gpgme-config
* Wed Jun 28 2006 zpetrova@suse.cz
- update to version 1.1.2
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Create devel subpackage [#140727]
* Sat Dec  3 2005 meissner@suse.de
- require libgpg-error-devel (since we include headers that
  include headers from there).
* Mon Nov 28 2005 zpetrova@suse.cz
- Update to version 1.0.3 (#135395).
* Thu Feb 17 2005 didge@suse.de
- update to stable version 1.0.2
- update of url
* Mon Jul 12 2004 adrian@suse.de
- update to version 0.9.0
  * support for gpg2
* Thu Mar 18 2004 didge@suse.de
- fixed bug #36194
* Fri Feb 27 2004 ro@suse.de
- added libgpg-error to neededforbuild
* Mon Feb  9 2004 didge@suse.de
- version 0.3.16
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Sep  2 2003 mc@suse.de
- add newpg, libgcrypt and libksba to neededforbuild again
  it is needed to support kmail with cryptplug
  fixed #29620, #29641 and #29642
* Mon Aug 11 2003 adrian@suse.de
- cleanup #neededforbuild and requires
* Tue Aug  5 2003 adrian@suse.de
- fix libtool handling to get shared libraries
* Thu May 22 2003 coolo@suse.de
- fixing info pages
* Wed Apr 16 2003 coolo@suse.de
- use BuildRoot
* Fri Feb 21 2003 mc@suse.de
- fixed -fPIC and lib64 Problems
* Thu Feb 20 2003 mc@suse.de
- update to version 0.3.15
* Thu Jan 30 2003 didge@suse.de
- Version 0.3.14
* Mon Oct 21 2002 didge@suse.de
- Version 0.3.12
* Wed Sep 25 2002 ro@suse.de
- removed bogus self-provides again
* Wed Sep 25 2002 didge@suse.de
- Version 0.3.11
* Tue Sep 10 2002 didge@suse.de
- Version 0.3.10
* Wed Jul 31 2002 didge@suse.de
- Version 0.3.8
* Fri Jun 21 2002 didge@suse.de
- New Version 0.3.7
* Fri May 10 2002 didge@suse.de
- New Version 0.3.6
* Tue May  7 2002 ro@suse.de
- fixed specfile: no macro allowed in Version: line
* Fri Mar  8 2002 didge@suse.de
- New Version 0.3.4
* Thu Feb 14 2002 didge@suse.de
- New Version 0.3.3
* Fri Jan  4 2002 didge@suse.de
- New Version 0.3.0
* Wed Oct 31 2001 didge@suse.de
- Fixed patch
* Mon Oct 29 2001 didge@suse.de
- Needs a patch to build on other platforms than i386
* Tue Oct  9 2001 didge@suse.de
- Version 0.2.3
- needs a patch to build because something is broken?!
* Thu Sep 13 2001 didge@suse.de
- Fix a bug to build under AXP
* Wed Aug 22 2001 didge@suse.de
- First build, Verison 0.2.2
